@@ -8,7 +8,7 @@ module Language.Haskell.TH.Compat.Data.Current (
 
 import Language.Haskell.TH
   (CxtQ, ConQ, TypeQ, DecQ,
-   Cxt, Con, Type, Name, TyVarBndr, Kind,
+   Cxt, Con, Type, Name, TyVarBndr, BndrVis, Kind,
    Dec (DataD, NewtypeD, DataInstD, NewtypeInstD, InstanceD),
    DerivClauseQ, DerivClause (..), Pred,
    dataD, newtypeD, dataInstD, newtypeInstD, derivClause, conT)
@@ -22,23 +22,23 @@ unDerivClause (DerivClause _ ps) = ps
 
 -- | Definition against 'dataD',
 --   compatible with before temaplate-haskell-2.11
-dataD' :: CxtQ -> Name -> [TyVarBndr ()] -> [ConQ] -> [Name]
+dataD' :: CxtQ -> Name -> [TyVarBndr BndrVis] -> [ConQ] -> [Name]
        -> DecQ
 dataD' cxt n bs cs ds = dataD cxt n bs Nothing cs $ derivesFromNames ds
 
 -- | Compatible interface to destruct 'DataD'
-unDataD :: Dec -> Maybe (Cxt, Name, [TyVarBndr ()], Maybe Kind, [Con], [Type])
+unDataD :: Dec -> Maybe (Cxt, Name, [TyVarBndr BndrVis], Maybe Kind, [Con], [Type])
 unDataD (DataD cxt n bs mk cs ds) = Just (cxt, n, bs, mk, cs, ds >>= unDerivClause)
 unDataD  _                        = Nothing
 
 -- | Definition against 'newtypeD',
 --   compatible with before temaplate-haskell-2.11
-newtypeD' :: CxtQ -> Name -> [TyVarBndr ()] -> ConQ -> [Name]
+newtypeD' :: CxtQ -> Name -> [TyVarBndr BndrVis] -> ConQ -> [Name]
           -> DecQ
 newtypeD' cxt n bs c ds = newtypeD cxt n bs Nothing c $ derivesFromNames ds
 
 -- | Compatible interface to destruct 'NewtypeD'
-unNewtypeD :: Dec -> Maybe (Cxt, Name, [TyVarBndr ()], Maybe Kind, Con, [Type])
+unNewtypeD :: Dec -> Maybe (Cxt, Name, [TyVarBndr BndrVis], Maybe Kind, Con, [Type])
 unNewtypeD (NewtypeD cxt n bs mk c ds) = Just (cxt, n, bs, mk, c, ds >>= unDerivClause)
 unNewtypeD  _                          = Nothing
 
